@@ -57,7 +57,8 @@ class QMarkdownTextEdit : public QPlainTextEdit {
     MarkdownHighlighter *highlighter();
     QPlainTextEditSearchWidget *searchWidget();
     void setIgnoredClickUrlSchemata(QStringList ignoredUrlSchemata);
-    void setIgnoredClickUrlRegexps(QList<QRegularExpression> ignoredClickUrlRegexps);
+    void setIgnoredClickUrlRegexps(
+        QList<QRegularExpression> ignoredClickUrlRegexps);
     virtual void openUrl(const QString &urlString, bool openInNewTab = false);
     QString getMarkdownUrlAtPosition(const QString &text, int position);
     void initSearchFrame(QWidget *searchFrame, bool darkMode = false);
@@ -73,6 +74,7 @@ class QMarkdownTextEdit : public QPlainTextEdit {
     void setLineNumbersCurrentLineColor(QColor color);
     void setLineNumbersOtherLineColor(QColor color);
     void setSearchWidgetDebounceDelay(uint debounceDelay);
+    void setBookmarkLines(const QHash<int, int> &bookmarkLines);
 
     void setHighlightingEnabled(bool enabled);
     [[nodiscard]] bool highlightingEnabled() const;
@@ -128,6 +130,7 @@ class QMarkdownTextEdit : public QPlainTextEdit {
     bool quotationMarkCheck(const QChar quotationCharacter);
     void focusOutEvent(QFocusEvent *event) override;
     void paintEvent(QPaintEvent *e) override;
+    static int listContentIndentLength(const QString &text);
     bool handleCharRemoval(MarkdownHighlighter::RangeType type, int block,
                            int position);
     void resizeEvent(QResizeEvent *event) override;
