@@ -272,6 +272,11 @@ class MainWindow : public QMainWindow {
 
     void onNavigationWidgetPositionClicked(int position);
 
+    void onNavigationWidgetHeadingRenamed(int position, const QString &oldText,
+                                          const QString &newText);
+
+    void updateBacklinksAfterHeadingRename(const QString &oldHeading, const QString &newHeading);
+
    private slots:
 
     void on_noteTextEdit_textChanged();
@@ -330,6 +335,10 @@ class MainWindow : public QMainWindow {
 
     void on_action_Forward_in_note_history_triggered();
 
+    void on_action_Previous_heading_triggered();
+
+    void on_action_Next_heading_triggered();
+
     void on_action_Shortcuts_triggered();
 
     void on_action_Knowledge_base_triggered();
@@ -720,6 +729,8 @@ class MainWindow : public QMainWindow {
 
     void on_actionCopy_path_to_note_to_clipboard_triggered();
 
+    void on_actionCopy_note_filename_to_clipboard_triggered();
+
     void on_actionMove_up_in_subfolder_list_triggered();
 
     void on_actionMove_down_in_subfolder_list_triggered();
