@@ -535,4 +535,128 @@ void TestNotes::testHTMLescape() {
     QVERIFY(result == expected);
 }
 
+/**
+ * Test that angle-bracket content like <stdio.h> inside various code block
+ * types is NOT converted to a file link in the preview HTML.
+ * See: https://github.com/pbek/QOwnNotes/issues/3084
+ */
+void TestNotes::testAngleBracketsInCodeBlocksNotConvertedToLinks() {
+    // Test backtick-fenced code block
+    {
+        QString md = QStringLiteral("# Test\n```c\n#include <stdio.h>\n```\n");
+        Note note;
+        note.setNoteText(md);
+        QString html = note.toMarkdownHtml("", 980, true);
+        // Should NOT contain a file link for stdio.h
+        QVERIFY(!html.contains(QStringLiteral("](file://")));
+        QVERIFY(!html.contains(QStringLiteral("[stdio.h]")));
+        // Should contain stdio.h as text (HTML-escaped angle brackets)
+        QVERIFY(html.contains(QStringLiteral("stdio.h")));
+    }
+
+    // Test tilde-fenced code block
+    {
+        QString md = QStringLiteral("# Test\n~~~c\n#include <stdio.h>\n~~~\n");
+        Note note;
+        note.setNoteText(md);
+        QString html = note.toMarkdownHtml("", 980, true);
+        QVERIFY(!html.contains(QStringLiteral("](file://")));
+        QVERIFY(!html.contains(QStringLiteral("[stdio.h]")));
+        QVERIFY(html.contains(QStringLiteral("stdio.h")));
+    }
+
+    // Test inline code
+    {
+        QString md = QStringLiteral("# Test\nUse `#include <stdio.h>` in C.\n");
+        Note note;
+        note.setNoteText(md);
+        QString html = note.toMarkdownHtml("", 980, true);
+        QVERIFY(!html.contains(QStringLiteral("](file://")));
+        QVERIFY(!html.contains(QStringLiteral("[stdio.h]")));
+        QVERIFY(html.contains(QStringLiteral("stdio.h")));
+    }
+
+    // Test 4-space indented code block
+    {
+        QString md = QStringLiteral("# Test\n\n    #include <stdio.h>\n\nSome text.\n");
+        Note note;
+        note.setNoteText(md);
+        QString html = note.toMarkdownHtml("", 980, true);
+        QVERIFY(!html.contains(QStringLiteral("](file://")));
+        QVERIFY(!html.contains(QStringLiteral("[stdio.h]")));
+        QVERIFY(html.contains(QStringLiteral("stdio.h")));
+    }
+
+    // Test tab-indented code block
+    {
+        QString md = QStringLiteral("# Test\n\n\t#include <stdlib.h>\n\nSome text.\n");
+        Note note;
+        note.setNoteText(md);
+        QString html = note.toMarkdownHtml("", 980, true);
+        QVERIFY(!html.contains(QStringLiteral("](file://")));
+        QVERIFY(!html.contains(QStringLiteral("[stdlib.h]")));
+        QVERIFY(html.contains(QStringLiteral("stdlib.h")));
+    }
+
+    // Test that angle brackets OUTSIDE code blocks still get converted
+    {
+        QString md = QStringLiteral("# Test\nSee <test.md> for details.\n");
+        Note note;
+        note.setNoteText(md);
+        QString html = note.toMarkdownHtml("", 980, true);
+        // Outside code blocks, <test.md> should become a link
+        QVERIFY(html.contains(QStringLiteral("test.md")));
+    }
+}
+
+/**
+ * Test that a backtick-fenced code block nested inside a tilde-fenced code
+ * block does not result in raw HTML span tags being visible in the preview.
+ * See: https://github.com/pbek/QOwnNotes/issues/2671
+ */
+void TestNotes::testBacktickBlockInsideTildeFenceNotDoubleHighlighted() {
+    // A tilde fence containing a backtick-fenced ini block
+    QString md = QStringLiteral("~~~\n```ini\ntest1=test2\n```\n~~~\n");
+
+    Note note;
+    note.setNoteText(md);
+    QString html = note.toMarkdownHtml("", 980, true);
+    // Raw HTML span tags must NOT appear as visible text in the output.
+    // Before the fix, the backtick block was highlighted first (injecting spans),
+    // then the outer tilde block processor escaped those spans, causing
+    // "&lt;span class=\"code-keyword\"&gt;test1&lt;/span&gt;=test2" to show up literally.
+    QVERIFY(!html.contains(QStringLiteral("&lt;span")));
+    QVERIFY(!html.contains(QStringLiteral("&gt;test1&lt;")));
+
+    // The raw content should still be present (as plain text, not wrapped in spans)
+    QVERIFY(html.contains(QStringLiteral("test1")));
+    QVERIFY(html.contains(QStringLiteral("test2")));
+}
+
+/**
+ * Test that a backtick-fenced code block nested inside a 4-space/tab indented
+ * code block does not result in raw HTML span tags being visible in the preview.
+ * See: https://github.com/pbek/QOwnNotes/issues/2671
+ */
+void TestNotes::testBacktickBlockInsideIndentedCodeNotHighlighted() {
+    // A tab-indented code block containing a backtick-fenced ini block
+    QString md = QStringLiteral("\t```ini\n\ttest1=test2\n\t```\n");
+
+    Note note;
+    note.setNoteText(md);
+    QString html = note.toMarkdownHtml("", 980, true);
+
+    // The entire block is a 4-space/tab indented code block, so MD4C renders
+    // it as a <pre><code> block. No highlighting should be injected — the
+    // backtick fences are literal content, not Markdown code fences.
+    // Before the fix, highlightCode would see the ```ini, run the INI
+    // highlighter, and inject <span class="code-keyword"> into the output.
+    QVERIFY2(!html.contains(QStringLiteral("<span class=\"code-keyword\">")),
+             "Indented code block content must not contain injected highlight spans");
+
+    // The raw content should be present
+    QVERIFY(html.contains(QStringLiteral("test1")));
+    QVERIFY(html.contains(QStringLiteral("test2")));
+}
+
 // QTEST_MAIN(TestNotes)
