@@ -37,6 +37,13 @@ class TestNotes : public QObject {
     void testOctal();
     void testHex();
     void testHTMLescape();
+
+    /* Code block angle-bracket protection tests (issue #3084) */
+    void testAngleBracketsInCodeBlocksNotConvertedToLinks();
+
+    /* Nested fence tests (issue #2671) */
+    void testBacktickBlockInsideTildeFenceNotDoubleHighlighted();
+    void testBacktickBlockInsideIndentedCodeNotHighlighted();
 };
 
 #endif    // TESTNOTES_H
